A bit more cleanup in translations.
[timetracker.git] / mysql.sql
index d9adc6e..d6e1d2d 100644 (file)
--- a/mysql.sql
+++ b/mysql.sql
 # This table stores settings common to all team members such as language, week start day, etc.
 #
 CREATE TABLE `tt_teams` (
-  `id` int(11) NOT NULL auto_increment,                  # team id
-  `timestamp` timestamp NOT NULL,                        # modification timestamp
-  `name` varchar(80) default NULL,                       # team name
-  `address` varchar(255) default NULL,                   # team address, used in invoices
-  `currency` varchar(7) default NULL,                    # team currency symbol
-  `decimal_mark` char(1) NOT NULL default '.',           # separator in decimals
-  `lang` varchar(10) NOT NULL default 'en',              # language
-  `date_format` varchar(20) NOT NULL default '%Y-%m-%d', # date format
-  `time_format` varchar(20) NOT NULL default '%H:%M',    # time format
-  `week_start` smallint(2) NOT NULL DEFAULT '0',         # Week start day, 0 == Sunday.
-  `tracking_mode` smallint(2) NOT NULL DEFAULT '1',      # tracking mode ("projects" or "projects and tasks")
-  `record_type` smallint(2) NOT NULL DEFAULT '0',        # time record type ("start and finish", "duration", or both)
-  `plugins` varchar(255) default NULL,                   # a list of enabled plugins for team
-  `lock_spec` varchar(255) default NULL,                 # Cron specification for record locking,
-                                                         # for example: "0 10 * * 1" for "weekly on Mon at 10:00".
-  `workday_hours` smallint(6) DEFAULT '8',               # number of work hours in a regular day
-  `custom_logo` tinyint(4) default '0',                  # whether to use a custom logo or not
-  `status` tinyint(4) default '1',                       # team status
+  `id` int(11) NOT NULL auto_increment,                      # team id
+  `timestamp` timestamp NOT NULL,                            # modification timestamp
+  `name` varchar(80) default NULL,                           # team name
+  `currency` varchar(7) default NULL,                        # team currency symbol
+  `decimal_mark` char(1) NOT NULL default '.',               # separator in decimals
+  `lang` varchar(10) NOT NULL default 'en',                  # language
+  `date_format` varchar(20) NOT NULL default '%Y-%m-%d',     # date format
+  `time_format` varchar(20) NOT NULL default '%H:%M',        # time format
+  `week_start` smallint(2) NOT NULL DEFAULT '0',             # Week start day, 0 == Sunday.
+  `tracking_mode` smallint(2) NOT NULL DEFAULT '1',          # tracking mode ("time", "projects" or "projects and tasks")
+  `project_required` smallint(2) NOT NULL DEFAULT '0',       # whether a project selection is required or optional
+  `task_required` smallint(2) NOT NULL DEFAULT '0',          # whether a task selection is required or optional
+  `record_type` smallint(2) NOT NULL DEFAULT '0',            # time record type ("start and finish", "duration", or both)
+  `uncompleted_indicators` smallint(2) NOT NULL DEFAULT '0', # whether to show indicators for users with uncompleted time entries
+  `bcc_email` varchar(100) default NULL,                     # bcc email to copy all reports to
+  `plugins` varchar(255) default NULL,                       # a list of enabled plugins for team
+  `lock_spec` varchar(255) default NULL,                     # Cron specification for record locking,
+                                                             # for example: "0 10 * * 1" for "weekly on Mon at 10:00".
+  `workday_hours` decimal(5,2) DEFAULT '8.00',               # number of work hours in a regular day
+  `custom_logo` tinyint(4) default '0',                      # whether to use a custom logo or not
+  `status` tinyint(4) default '1',                           # team status
   PRIMARY KEY (`id`)
 );
 
@@ -138,8 +141,9 @@ CREATE TABLE `tt_log` (
   `project_id` int(11) default NULL,   # project id
   `task_id` int(11) default NULL,      # task id
   `invoice_id` int(11) default NULL,   # invoice id
-  `comment` blob,                      # user provided comment for time record
+  `comment` text,                      # user provided comment for time record
   `billable` tinyint(4) default '0',   # whether the record is billable or not
+  `paid` tinyint(4) default '0',       # whether the record is paid
   `status` tinyint(4) default '1',     # time record status
   PRIMARY KEY (`id`)
 );
@@ -187,18 +191,21 @@ CREATE TABLE `tt_fav_reports` (
   `id` int(11) NOT NULL auto_increment,                  # favorite report id
   `name` varchar(200) NOT NULL,                          # favorite report name
   `user_id` int(11) NOT NULL,                            # user id favorite report belongs to
+  `report_spec` text default NULL,                       # future replacement field for all report settings
   `client_id` int(11) default NULL,                      # client id (if selected)
   `cf_1_option_id` int(11) default NULL,                 # custom field 1 option id (if selected)
   `project_id` int(11) default NULL,                     # project id (if selected)
   `task_id` int(11) default NULL,                        # task id (if selected)
   `billable` tinyint(4) default NULL,                    # whether to include billable, not billable, or all records
   `invoice` tinyint(4) default NULL,                     # whether to include invoiced, not invoiced, or all records
+  `paid_status` tinyint(4) default NULL,                 # whether to include paid, not paid, or all records
   `users` text default NULL,                             # Comma-separated list of user ids. Nothing here means "all" users.
   `period` tinyint(4) default NULL,                      # selected period type for report
   `period_start` date default NULL,                      # period start
   `period_end` date default NULL,                        # period end
   `show_client` tinyint(4) NOT NULL default '0',         # whether to show client column
   `show_invoice` tinyint(4) NOT NULL default '0',        # whether to show invoice column
+  `show_paid` tinyint(4) NOT NULL default '0',           # whether to show paid column
   `show_project` tinyint(4) NOT NULL default '0',        # whether to show project column
   `show_start` tinyint(4) NOT NULL default '0',          # whether to show start field
   `show_duration` tinyint(4) NOT NULL default '0',       # whether to show duration field
@@ -209,6 +216,7 @@ CREATE TABLE `tt_fav_reports` (
   `show_custom_field_1` tinyint(4) NOT NULL default '0', # whether to show custom field 1
   `show_totals_only` tinyint(4) NOT NULL default '0',    # whether to show totals only
   `group_by` varchar(20) default NULL,                   # group by field
+  `status` tinyint(4) default '1',                       # favorite report status
   PRIMARY KEY (`id`)
 );
 
@@ -224,6 +232,9 @@ CREATE TABLE `tt_cron` (
   `next` int(11) default NULL,                  # UNIX timestamp of when to run next job
   `report_id` int(11) default NULL,             # report id from tt_fav_reports, a report to mail on schedule
   `email` varchar(100) default NULL,            # email to send results to
+  `cc` varchar(100) default NULL,               # cc email to send results to
+  `subject` varchar(100) default NULL,          # email subject
+  `report_condition` varchar(255) default NULL, # report condition, "count > 0" for sending not empty reports
   `status` tinyint(4) default '1',              # entry status
   PRIMARY KEY (`id`)
 );
@@ -326,9 +337,10 @@ CREATE TABLE `tt_expense_items` (
   `user_id` int(11) NOT NULL,          # user id the expense item is reported by
   `client_id` int(11) default NULL,    # client id
   `project_id` int(11) default NULL,   # project id
-  `name` varchar(255) NOT NULL,        # expense item name (what is an expense for)
+  `name` text NOT NULL,                # expense item name (what is an expense for)   
   `cost` decimal(10,2) default '0.00', # item cost (including taxes, etc.)
   `invoice_id` int(11) default NULL,   # invoice id
+  `paid` tinyint(4) default '0',       # whether the item is paid
   `status` tinyint(4) default '1',     # item status
   PRIMARY KEY  (`id`)
 );
@@ -340,19 +352,31 @@ create index client_idx on tt_expense_items(client_id);
 create index project_idx on tt_expense_items(project_id);
 create index invoice_idx on tt_expense_items(invoice_id);
 
+
 #
-# Structure for table tt_monthly_quota.
-# This table lists monthly quota per team.
+# Structure for table tt_predefined_expenses.
+# This table keeps names and costs for predefined expenses.
 #
+CREATE TABLE `tt_predefined_expenses` (
+  `id` int(11) NOT NULL auto_increment, # predefined expense id
+  `team_id` int(11) NOT NULL,           # team id
+  `name` varchar(255) NOT NULL,         # predefined expense name, such as mileage
+  `cost` decimal(10,2) default '0.00',  # cost for one unit
+  PRIMARY KEY  (`id`)
+);
+
 
-CREATE TABLE `tt_monthly_quota` (
-  `team_id` int(11) NOT NULL,             # team's id
-  `year` smallint(5) UNSIGNED NOT NULL,   # year we'setting monthly quota for
-  `month` tinyint(3) UNSIGNED NOT NULL,   # month we're settng monthly quota for
-  `quota` smallint(5) UNSIGNED NOT NULL,  # the monthly quota
-  PRIMARY KEY (`year`,`month`,`team_id`)
+#
+# Structure for table tt_monthly_quotas.
+# This table keeps monthly work hour quotas for teams.
+#
+CREATE TABLE `tt_monthly_quotas` (
+  `team_id` int(11) NOT NULL,             # team id
+  `year` smallint(5) UNSIGNED NOT NULL,   # quota year
+  `month` tinyint(3) UNSIGNED NOT NULL,   # quota month
+  `quota` decimal(5,2) NOT NULL,          # number of work hours in specified month and year
+  PRIMARY KEY (`team_id`,`year`,`month`)
 );
 
-ALTER TABLE `tt_monthly_quota`
+ALTER TABLE `tt_monthly_quotas`
   ADD CONSTRAINT `FK_TT_TEAM_CONSTRAING` FOREIGN KEY (`team_id`) REFERENCES `tt_teams` (`id`) ON DELETE CASCADE ON UPDATE CASCADE;
-